Welcome to MyTB (My Toolbox)

MyTB is just another collection of handy and useful python functions and modules.

.. image:: https://travis-ci.org/feenes/mytb.svg?branch=master
    :target: https://travis-ci.org/feenes/mytb


It can be found at https://github.com/feenes/mytb.git

It tries to be modular in order to consume as little memory (RAM) as possible.
